<?php
/**
*
* search_ignore_words [English]
*
* @package language
* @version $Id$
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

if (!defined('IN_PHPBB'))
{
	exit;
}

$words = array(
	'a',
	'about',
	'after',
	'ago',
	'all',
	'almost',
	'along',
	'alot',
	'also',
	'am',
	'an',
	'and',
	'answer',
	'any',
	'anybody',
	'anybodys',
	'anywhere',
	'are',
	'arent',
	'around',
	'as',
	'ask',
	'askd',
	'at',
	'bad',
	'be',
	'because',
	'been',
	'before',
	'being',
	'best',
	'better',
	'between',
	'big',
	'btw',
	'but',
	'by',
	'can',
	'cant',
	'come',
	'could',
	'couldnt',
	'day',
	'days',
	'days',
	'did',
	'didnt',
	'do',
	'does',
	'doesnt',
	'dont',
	'down',
	'each',
	'etc',
	'either',
	'else',
	'even',
	'ever',
	'every',
	'everybody',
	'everybodys',
	'everyone',
	'far',
	'find',
	'for',
	'found',
	'from',
	'get',
	'go',
	'going',
	'gone',
	'good',
	'got',
	'gotten',
	'had',
	'has',
	'have',
	'havent',
	'having',
	'her',
	'here',
	'hers',
	'him',
	'his',
	'home',
	'how',
	'hows',
	'href',
	'I',
	'Ive',
	'if',
	'in',
	'ini',
	'into',
	'is',
	'isnt',
	'it',
	'its',
	'its',
	'just',
	'know',
	'large',
	'less',
	'like',
	'liked',
	'little',
	'looking',
	'look',
	'looked',
	'looking',
	'lot',
	'maybe',
	'many',
	'me',
	'more',
	'most',
	'much',
	'must',
	'mustnt',
	'my',
	'near',
	'need',
	'never',
	'new',
	'news',
	'no',
	'none',
	'not',
	'nothing',
	'now',
	'of',
	'off',
	'often',
	'old',
	'on',
	'once',
	'only',
	'oops',
	'or',
	'other',
	'our',
	'ours',
	'out',
	'over',
	'page',
	'please',
	'put',
	'question',
	'questions',
	'questioned',
	'quote',
	'rather',
	'really',
	'recent',
	'said',
	'saw',
	'say',
	'says',
	'she',
	'see',
	'sees',
	'should',
	'sites',
	'small',
	'so',
	'some',
	'something',
	'sometime',
	'somewhere',
	'soon',
	'take',
	'than',
	'true',
	'thank',
	'that',
	'thatd',
	'thats',
	'the',
	'their',
	'theirs',
	'theres',
	'theirs',
	'them',
	'then',
	'there',
	'these',
	'they',
	'theyll',
	'theyd',
	'theyre',
	'this',
	'those',
	'though',
	'through',
	'thus',
	'time',
	'times',
	'to',
	'too',
	'under',
	'until',
	'untrue',
	'up',
	'upon',
	'use',
	'users',
	'version',
	'very',
	'via',
	'want',
	'was',
	'way',
	'we',
	'well',
	'went',
	'were',
	'werent',
	'what',
	'when',
	'where',
	'which',
	'who',
	'whom',
	'whose',
	'why',
	'wide',
	'will',
	'with',
	'within',
	'without',
	'wont',
	'world',
	'worse',
	'worst',
	'would',
	'wrote',
	'www',
	'yes',
	'yet',
	'you',
	'youd',
	'youll',
	'your',
	'youre',
	'yours',
	'AFAIK',
	'IIRC',
	'LOL',
	'ROTF',
	'ROTFLMAO',
	'YMMV',
);

?>